/*
 * mp3plot - Bitrate analysis tool
 *
 * Copyright (C) 2007, 2009 Toni Corvera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

// $Id: bitrate.cc 1701 2009-04-24 20:17:10Z  $

#include "bitrate.h"

#include <iostream>
#include <bitset>
#include <cassert>

namespace mp3plot {

namespace mp3 {

// All methods in standard_bitrates are static

bool standard_bitrates::init_done = false;
standard_bitrates::bitrate_vector standard_bitrates::bitrates;

void standard_bitrates::init() {
    if (init_done) return;

    // Invariant
    assert( bad_bitrate() < 0 );

    // The indices match the 4-bit header indication of bitrate
    static const bitrate_t BITRATES[] = {
        0,      // Free-form bitrate
        32,
        40,
        48,
        56,
        64,
        80,
        96,
        112,
        128,
        160,
        192,
        224,
        256,
        320,
        bad_bitrate(), // Bad bitrate
    };

    bitrates = std::vector<bitrate_t>(BITRATES, BITRATES+sizeof(BITRATES)/sizeof(bitrate_t));

    init_done = true;
}

const std::vector<bitrate_t> standard_bitrates::as_vector() {
    init();
    return bitrates;
}

bitrate_t standard_bitrates::bad_bitrate() {
    return -1;
}

bitrate_t standard_bitrates::get(uint8_t bitrate_header_id) {
    return as_vector()[ bitrate_header_id ];
}

std::ostream & operator<<(std::ostream & os, const standard_bitrates::bitrate_vector & v) {
    int n=0;
    for (std::vector<bitrate_t>::const_iterator it = v.begin();
         it != v.end();
         ++it)
    {
        os << "[" << std::bitset<4>(n++) << "] = " << *it;
        if (*it == standard_bitrates::bad_bitrate()) {
            os << " (invalid)";
        }
        else if (*it == 0) {
            os << " (free-form)";
        }
        os << "\n";
    }

    return os;
}

} // namespace mp3

} // namespace mp3plot

// vim:set ts=4 et ai:

