/*
 * mp3plot - Bitrate analysis tool
 *
 * Copyright (C) 2007, 2009 Toni Corvera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

// $Id: bitrate.h 1637 2009-04-14 02:10:48Z  $

#ifndef MP3PLOT_MP3_BITRATE_H
#define MP3PLOT_MP3_BITRATE_H

#include <vector>

#include "../mp3_config.h"
#include "../common.h"

namespace mp3plot {

namespace mp3 {

    /*!
     * \brief Interface to the set of standard bitrates
     */
    class standard_bitrates {
    public:
        typedef std::vector<bitrate_t> bitrate_vector;
    private:
        static bool init_done;
        static void init();
        static bitrate_vector bitrates;
    public:
        /*!
         * \brief Returns a vector of the standard bitrates
         */
        static const bitrate_vector as_vector();

        /*!
         * \brief Returns the bitrate corresponding to a bitrate id
         * \remarks The id is the number used in the MP3 headers to refer to that bitrate
         * \param[in] bitrate_header_id Id of the bitrate (see remarks)
         */
        static bitrate_t get(uint8_t bitrate_header_id);

        /*!
         * \brief Returns the number of standard bitrates
         */
        static size_t number() {
            init();
            return as_vector().size();
        }

        /*!
         * \brief Returns the bad bitrate symbolic value
         * \remarks The bad bitrate has obviouly no bitrate associated, this value
         *          is used through the code to represet it
         */
        static bitrate_t bad_bitrate();
    };

    // Forward declaration
    /*!
     * \brief Output operator for bitrate vectors, for debugging purposes.
     * Prints a list that matches bitrate ids with the associated nominal bitrate.
     */
    std::ostream & operator<<(std::ostream &, const standard_bitrates::bitrate_vector &);

} // namespace mp3

} // namespace mp3plot

#endif // MP3PLOT_MP3_BITRATE_H
// vim:set ts=4 et ai:

