/*
 * Copyright (C) 2006-2007 Toni Corvera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

// $Id: named_file.hxx 1581 2009-04-01 23:29:35Z  $

#ifndef ONET_NAMED_FILE_H
#define ONET_NAMED_FILE_H

#include <string>

#include <iostream>

namespace net_outlyer {

namespace file {

/*!
 * \brief Abstract Base Class for files that store the filename.
 */
class named_file {
    public:
        /*!
         * \brief Consult the filename.
         */
        const std::string & name() const { return name_; }

    protected:
        //! Default constructor
        explicit named_file(const std::string & name)
            : name_(name)
        {}

        //! Copy constructor
        named_file(const named_file & nf)
            : name_(nf.name_)
        {}

        //! Destructor, nothing to do here
        ~named_file() {}

        /*!
         * \brief Equivalence operator.
         * Two named_file's are equivalent if the name is equal.
         */
        bool operator==(const named_file & nf) const {
            if (this == &nf) { return true; }
            return nf.name_ == name_;
        }
    private:
        //! The file name
        const std::string name_;
};

}

}

#endif // ONET_NAMED_FILE_H
// vim:set ts=4 et ai:

