/*
 * mp3plot - Bitrate analysis tool
 *
 * Copyright (C) 2007, 2009 Toni Corvera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

// $Id: named_fstream.hxx 1583 2009-04-03 00:45:38Z  $

#ifndef ONET_NAMED_FSTREAM_HXX
#define ONET_NAMED_FSTREAM_HXX

#include <fstream>
#include <string>

#include "named_file.hxx"
#include "constraints.hxx"

namespace net_outlyer {

//! Classes and methods for file handling
namespace file {

    using std::ofstream;
    using std::ifstream;
    using std::fstream;
    using std::string;
    using std::ios_base;

    template<typename stream_type>
    struct named_ios : public named_file {
        named_ios(const string& fn) : named_file(fn)
        {
            constraints::derived_from<stream_type, std::ios>();
        }
    };

    class named_ofstream : public ofstream, public named_ios<ofstream> {
    public:
        named_ofstream(const string & fn, ios_base::openmode mode = ios_base::out)
            : ofstream(fn.c_str(), mode), named_ios<ofstream>(fn)
        {}
    };

    class named_ifstream : public ifstream, public named_ios<ifstream> {
    public:
        named_ifstream(const string & fn, ios_base::openmode mode = ios_base::in)
            : ifstream(fn.c_str(), mode), named_ios<ifstream>(fn)
        {}
    };

    class named_fstream : public fstream, public named_ios<fstream> {
    public:
        named_fstream(const string & fn, ios_base::openmode mode = ios_base::in|ios_base::out)
            : fstream(fn.c_str(), mode), named_ios<fstream>(fn)
        {}
    };

} // namespace file

} // namespace net_outlyer

#endif // ONET_NAMED_FSTREAM_HXX
// vim:set ts=4 et ai:

